@@ -39,7 +39,7 @@ class monday_endpoints:
                 }, json={
                     "query":str(body)
                 })
-
+                print(request.json())
                 if request.status_code == 403:
                     logging.critical("API user is not authorized.")
                     raise Exception("User is not authorized")
@@ -378,7 +378,7 @@ class monday_endpoints:
         Get board items and their column values.
         """
 
-        request_body = "query { boards (ids: " + str(board_id) + ",limit:25, page:0) { items { id, name, creator_id, name, state, updated_at column_values { id title value } group { id title }}}}"
+        request_body = "query { boards (ids: " + str(board_id) + ",limit:25, page:0) { items { id, name, creator_id, name, state, updated_at column_values { id title value text } group { id title }}}}"
         get_board_items_request = self.make_request(request_body)
         return get_board_items_request
 
